@@ -1,17 +1,4 @@
---------------------------------------------------------------------
--- |
--- Module    : Text.JSON.String
--- Copyright : (c) Galois, Inc. 2007-2009
--- License   : BSD3
---
--- Maintainer:  Sigbjorn Finne <sof@galois.com>
--- Stability :  provisional
--- Portability: portable
---
---------------------------------------------------------------------
---
--- Basic support for working with JSON values.
---
+-- | Basic support for working with JSON values.
 
 module Text.JSON.String 
      ( 
@@ -47,7 +34,9 @@ import Text.JSON.Types (JSValue(..),
                         JSString, toJSString, fromJSString,
                         JSObject, toJSObject, fromJSObject)
 
-import Control.Monad (liftM)
+import Control.Monad (liftM, ap)
+import Control.Applicative((<$>))
+import qualified Control.Applicative as A
 import Data.Char (isSpace, isDigit, digitToInt)
 import Data.Ratio (numerator, denominator, (%))
 import Numeric (readHex, readDec, showHex)
@@ -59,6 +48,10 @@ import Numeric (readHex, readDec, showHex)
 newtype GetJSON a = GetJSON { un :: String -> Either String (a,String) }
 
 instance Functor GetJSON where fmap = liftM
+instance A.Applicative GetJSON where
+  pure  = return
+  (<*>) = ap
+
 instance Monad GetJSON where
   return x        = GetJSON (\s -> Right (x,s))
   fail x          = GetJSON (\_ -> Left x)
@@ -81,9 +74,6 @@ getInput    = GetJSON (\s -> Right (s,s))
 setInput   :: String -> GetJSON ()
 setInput s  = GetJSON (\_ -> Right ((),s))
 
-(<$>) :: Functor f => (a -> b) -> f a -> f b
-x <$> y = fmap x y
-
 -------------------------------------------------------------------------
 
 -- | Find 8 chars context, for error messages
@@ -170,12 +160,12 @@ readJSRational = do
        '0' -> frac 0 cs
        _ 
         | not (isDigit c) -> fail $ "Unable to parse JSON Rational: " ++ context cs
-	| otherwise -> readDigits (digitToIntI c) cs
+        | otherwise -> readDigits (digitToIntI c) cs
 
    readDigits acc [] = frac (fromInteger acc) []
    readDigits acc (x:xs)
     | isDigit x = let acc' = 10*acc + digitToIntI x in 
-	          acc' `seq` readDigits acc' xs
+                      acc' `seq` readDigits acc' xs
     | otherwise = frac (fromInteger acc) (x:xs)
 
    frac n ('.' : ds) = 
